<?php

/**
 * @file
 * Administration forms for the LikeBtn module.
 */

/**
 * Menu callback; Displays the administration settings for LikeBtn.
 */
function likebtn_admin_settings() {
  $form = array();

  // Get all available content types.
  $types = node_type_get_types();
  $options = array();
  foreach ($types as $type) {
    $options[$type->type] = $type->name;
  }

  // Get all available entities view modes.
  $view_modes = entity_get_info('node');
  foreach ($view_modes['view modes'] as $view_mode_id => $view_mode_info) {
    $view_modes_options[$view_mode_id] = $view_mode_info['label'];
  }

  $form['likebtn_hint'] = array(
    '#type'          => 'item',
    '#description'   => t('You can set up the Like Button globally on this page, or per content type as a field in <a href="@link-manage_fields">Structure » Content types » Manage fields</a>.',
      array(
        '@link-manage_fields'   => url('admin/structure/types'),
      )
    ),
  );

  $form['likebtn_nodetypes'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Enable for the following content types'),
    '#description'   => t('Select the content types for which you want to activate like button.'),
    '#default_value' => variable_get('likebtn_nodetypes', array()),
    '#options'       => $options,
  );

  $form['likebtn_comments_nodetypes'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Enable for comments to the following content types'),
    '#description'   => t('Select the content types for comments to which you want to activate like button.'),
    '#default_value' => variable_get('likebtn_comments_nodetypes', array()),
    '#options'       => $options,
    '#disabled'      => !module_exists('comment'),
  );

  $form['likebtn_view_modes'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Entities view modes'),
    '#description'   => t('When will the like button be displayed?'),
    '#default_value' => variable_get('likebtn_view_modes', array()),
    '#options'       => $view_modes_options,
  );

  $form['likebtn_weight'] = array(
    '#type'          => 'select',
    '#title'         => t('Position'),
    '#description'   => t('The more the weight, the lower like button position in the entity.'),
    '#default_value' => variable_get('likebtn_weight', 10),
    '#options'       => array(
      -100 => '-100',
      -50  => '-50',
      -20  => '-20',
      -10  => '-10',
      -5   => '-5',
      5    => '5',
      10   => '10',
      20   => '20',
      50   => '50',
      100  => '100',
    ),
  );

  $form = array_merge($form, _likebtn_settings_form());

  return system_settings_form($form);
}
